Crate disposition_model_common

Crate disposition_model_common 

Common types shared between disposition_model and disposition_ir.

Modules

edge
entity
theme

Macros

id
Returns an Id validated at compile time.

Structs

Id
Unique identifier for any entity in the diagram, Cow<'static, str> newtype.
IdInvalidFmt
Error indicating Id provided is not in the correct format.
Map
A hash table where the iteration order of the key-value pairs is independent of the hash values of the keys.